@@ -20,11 +20,15 @@
 #define KCM_KSCREEN_H
 
 #include <KCModule>
-#include <QDeclarativeListProperty>
 
 class Widget;
 class QTimer;
 
+namespace KScreen
+{
+class ConfigOperation;
+}
+
 class KCMKScreen : public KCModule
 {
     Q_OBJECT
@@ -39,6 +43,8 @@ class KCMKScreen : public KCModule
     virtual void defaults();
 
   private:
+    void configReady(KScreen::ConfigOperation *op);
+
     Widget *mKScreenWidget;
 
 };
