@@ -59,9 +59,8 @@ KScreen::ConfigPtr testScreenConfig::loadConfig(const QByteArray& fileName)
 {
     KScreen::BackendManager::instance()->shutdownBackend();
 
-    QByteArray path(TEST_DATA);
-    path.append("/" + fileName);
-    setenv("TEST_DATA", path, 1);
+    QByteArray path(TEST_DATA "configs/" + fileName);
+    qputenv("TEST_DATA", path);
     qDebug() << path;
 
     KScreen::GetConfigOperation *op = new KScreen::GetConfigOperation;
@@ -85,6 +84,7 @@ void testScreenConfig::cleanupTestCase()
 void testScreenConfig::singleOutput()
 {
     const ConfigPtr currentConfig = loadConfig("singleOutput.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -102,6 +102,7 @@ void testScreenConfig::singleOutput()
 void testScreenConfig::laptopLidOpenAndExternal()
 {
     const ConfigPtr currentConfig = loadConfig("laptopAndExternal.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -125,6 +126,7 @@ void testScreenConfig::laptopLidOpenAndExternal()
 void testScreenConfig::laptopLidOpenAndTwoExternal()
 {
     const ConfigPtr currentConfig = loadConfig("laptopLidOpenAndTwoExternal.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -155,6 +157,7 @@ void testScreenConfig::laptopLidOpenAndTwoExternal()
 void testScreenConfig::laptopLidClosedAndExternal()
 {
     const ConfigPtr currentConfig = loadConfig("laptopAndExternal.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -177,6 +180,7 @@ void testScreenConfig::laptopLidClosedAndExternal()
 void testScreenConfig::laptopLidClosedAndThreeExternal()
 {
     const ConfigPtr currentConfig = loadConfig("laptopLidClosedAndThreeExternal.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -211,6 +215,7 @@ void testScreenConfig::laptopLidClosedAndThreeExternal()
 void testScreenConfig::laptopDockedLidOpenAndExternal()
 {
     const ConfigPtr currentConfig = loadConfig("laptopAndExternal.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -236,6 +241,7 @@ void testScreenConfig::laptopDockedLidOpenAndExternal()
 void testScreenConfig::laptopDockedLidClosedAndExternal()
 {
     const ConfigPtr currentConfig = loadConfig("laptopAndExternal.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -259,6 +265,7 @@ void testScreenConfig::laptopDockedLidClosedAndExternal()
 void testScreenConfig::workstationWithoutScreens()
 {
     const ConfigPtr currentConfig = loadConfig("workstationWithoutScreens.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -273,6 +280,7 @@ void testScreenConfig::workstationWithoutScreens()
 void testScreenConfig::workstationWithNoConnectedScreens()
 {
     const ConfigPtr currentConfig = loadConfig("workstationWithNoConnectedScreens.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -291,6 +299,7 @@ void testScreenConfig::workstationWithNoConnectedScreens()
 void testScreenConfig::workstationTwoExternalSameSize()
 {
     const ConfigPtr currentConfig = loadConfig("workstaionTwoExternalSameSize.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -315,6 +324,7 @@ void testScreenConfig::workstationTwoExternalSameSize()
 void testScreenConfig::workstationFallbackMode()
 {
     const ConfigPtr currentConfig = loadConfig("workstationFallbackMode.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -340,6 +350,7 @@ void testScreenConfig::workstationTwoExternalDiferentSize()
 {
 
     const ConfigPtr currentConfig = loadConfig("workstationTwoExternalDiferentSize.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -363,6 +374,7 @@ void testScreenConfig::workstationTwoExternalDiferentSize()
 void testScreenConfig::switchDisplayTwoScreens()
 {
     const ConfigPtr currentConfig = loadConfig("switchDisplayTwoScreens.json");
+    QVERIFY(currentConfig);
 
     Generator* generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
@@ -434,6 +446,7 @@ void testScreenConfig::switchDisplayTwoScreens()
 void testScreenConfig::switchDisplayTwoScreensNoCommonMode()
 {
     const ConfigPtr currentConfig = loadConfig("switchDisplayTwoScreensNoCommonMode.json");
+    QVERIFY(currentConfig);
 
     Generator *generator = Generator::self();
     generator->setCurrentConfig(currentConfig);
